==> spip_3.2.11.orig.tar.xz: ecrire/charsets/translit.php <==
<?php

/**
 * Déclaration pour la translitteration simple des correspondances entre
 * caractères unicodes spécifiques et caractères simples la plage ASCII
 *
 * @package SPIP\Core\Charsets
 **/

$GLOBALS['CHARSET']['translit'] = array(
// latin [fausse plage]
	128 => 'EUR',
	131 => 'f',
	140 => 'OE',
	147 => '\'\'',
	148 => '\'\'',
	153 => '(TM)',
	156 => 'oe',
	159 => 'Y',

// latin [legal]
	160 => ' ',
	161 => '!',
	162 => 'c',
	163 => 'L',
	164 => 'O',
	165 => 'yen',
	166 => '|',
	167 => 'p',
	169 => '(c)',
	171 => '<<',
	172 => '-',
	173 => '-',
	174 => '(R)',
	176 => 'o',
	177 => '+-',
	181 => 'mu',
	182 => 'p',
	183 => '.',
	186 => 'o ',
	187 => '>>',
	191 => '?',
	192 => 'A',
	193 => 'A',
	194 => 'A',
	195 => 'A',
	196 => 'A',
	197 => 'A',
	198 => 'AE',
	199 => 'C',
	200 => 'E',
	201 => 'E',
	202 => 'E',
	203 => 'E',
	204 => 'I',
	205 => 'I',
	206 => 'I',
	207 => 'I',
	209 => 'N',
	210 => 'O',
	211 => 'O',
	212 => 'O',
	213 => 'O',
	214 => 'O',
	216 => 'O',
	217 => 'U',
	218 => 'U',
	219 => 'U',
	220 => 'U',
	223 => 'ss',
	224 => 'a',
	225 => 'a',
	226 => 'a',
	227 => 'a',
	228 => 'a',
	229 => 'a',
	230 => 'ae',
	231 => 'c',
	232 => 'e',
	233 => 'e',
	234 => 'e',
	235 => 'e',
	236 => 'i',
	237 => 'i',
	238 => 'i',
	239 => 'i',
	241 => 'n',
	242 => 'o',
	243 => 'o',
	244 => 'o',
	245 => 'o',
	246 => 'o',
	248 => 'o',
	249 => 'u',
	250 => 'u',
	251 => 'u',
	252 => 'u',
	255 => 'y',

// turc
	286 => 'G',
	287 => 'g',
	304 => 'I',
	305 => 'i',
	350 => 'S',
	351 => 's',

// esperanto
	264 => 'Cx',
	265 => 'cx',
	284 => 'Gx',
	285 => 'gx',
	292 => 'Hx',
	293 => 'hx',
	308 => 'Jx',
	309 => 'jx',
	348 => 'Sx',
	349 => 'sx',
	364 => 'Ux',
	365 => 'ux',


// latin2 [Czech]
	283 => 'e',
	353 => 's',
	269 => 'c',
	345 => 'r',
	382 => 'z',
	367 => 'u',
	328 => 'n',
	357 => 't',
	271 => 'd',
	449 => 'o',
	282 => 'E',
	352 => 'S',
	268 => 'C',
	344 => 'R',
	381 => 'Z',
	366 => 'U',
	327 => 'N',
	356 => 'T',
	270 => 'D',
	467 => 'O',

// francais
	338 => 'OE',
	339 => 'oe',
	376 => 'Y',
	402 => 'f',

//polskie
	260 => 'A',
	261 => 'a',
	262 => 'C',
	263 => 'c',
	280 => 'E',
	281 => 'e',
	321 => 'L',
	322 => 'l',
	323 => 'N',
	324 => 'n',
	346 => 'S',
	347 => 's',
	377 => 'Z',
	378 => 'z',
	379 => 'Z',
	380 => 'z',

//roumain
	258 => 'A',
	259 => 'a',
	350 => 'S',
	351 => 's',
	354 => 'T',
	355 => 't',

// cyrillique
	1026 => 'D%',
	1027 => 'G%',
	8218 => '\'',
	1107 => 'g%',
	8222 => '"',
	8230 => '...',
	8224 => '/-',
	8225 => '/=',
	8364 => 'EUR',
	8240 => '0/00',
	1033 => 'LJ',
	8249 => '<',
	1034 => 'NJ',
	1036 => 'KJ',
	1035 => 'Ts',
	1039 => 'DZ',
	1106 => 'd%',
	8216 => '`',
	8217 => '\'',
	8220 => '"',
	8221 => '"',
	8226 => ' o ',
	8211 => '-',
	8212 => '--',
	8212 => '~',
	8482 => '(TM)',
	1113 => 'lj',
	8250 => '>',
	1114 => 'nj',
	1116 => 'kj',
	1115 => 'ts',
	1119 => 'dz',
	1038 => 'V%',
	1118 => 'v%',
	1032 => 'J%',
	1168 => 'G3',
	1025 => 'IO',
	1028 => 'IE',
	1031 => 'YI',
	1030 => 'II',
	1110 => 'ii',
	1169 => 'g3',
	1105 => 'io',
	8470 => 'No.',
	1108 => 'ie',
	1112 => 'j%',
	1029 => 'DS',
	1109 => 'ds',
	1111 => 'yi',
	1040 => 'A',
	1041 => 'B',
	1042 => 'V',
	1043 => 'G',
	1044 => 'D',
	1045 => 'E',
	1046 => 'ZH',
	1047 => 'Z',
	1048 => 'I',
	1049 => 'J',
	1050 => 'K',
	1051 => 'L',
	1052 => 'M',
	1053 => 'N',
	1054 => 'O',
	1055 => 'P',
	1056 => 'R',
	1057 => 'S',
	1058 => 'T',
	1059 => 'U',
	1060 => 'F',
	1061 => 'H',
	1062 => 'C',
	1063 => 'CH',
	1064 => 'SH',
	1065 => 'SCH',
	1066 => '"',
	1067 => 'Y',
	1068 => '\'',
	1069 => '`E',
	1070 => 'YU',
	1071 => 'YA',
	1072 => 'a',
	1073 => 'b',
	1074 => 'v',
	1075 => 'g',
	1076 => 'd',
	1077 => 'e',
	1078 => 'zh',
	1079 => 'z',
	1080 => 'i',
	1081 => 'j',
	1082 => 'k',
	1083 => 'l',
	1084 => 'm',
	1085 => 'n',
	1086 => 'o',
	1087 => 'p',
	1088 => 'r',
	1089 => 's',
	1090 => 't',
	1091 => 'u',
	1092 => 'f',
	1093 => 'h',
	1094 => 'c',
	1095 => 'ch',
	1096 => 'sh',
	1097 => 'sch',
	1098 => '"',
	1099 => 'y',
	1100 => '\'',
	1101 => '`e',
	1102 => 'yu',
	1103 => 'ya',

// vietnamien en translitteration de base
	7843 => 'a',
	7841 => 'a',
	7845 => 'a',
	7847 => 'a',
	7849 => 'a',
	7851 => 'a',
	7853 => 'a',
	7855 => 'a',
	7857 => 'a',
	7859 => 'a',
	7861 => 'a',
	7863 => 'a',
	7842 => 'A',
	7840 => 'A',
	7844 => 'A',
	7846 => 'A',
	7848 => 'A',
	7850 => 'A',
	7852 => 'A',
	7854 => 'A',
	7856 => 'A',
	7858 => 'A',
	7860 => 'A',
	7862 => 'A',
	7867 => 'e',
	7869 => 'e',
	7865 => 'e',
	7871 => 'e',
	7873 => 'e',
	7875 => 'e',
	7877 => 'e',
	7879 => 'e',
	7866 => 'E',
	7868 => 'E',
	7864 => 'E',
	7870 => 'E',
	7872 => 'E',
	7874 => 'E',
	7876 => 'E',
	7878 => 'E',
	7881 => 'i',
	7883 => 'i',
	7880 => 'I',
	7882 => 'I',
	7887 => 'o',
	7885 => 'o',
	7889 => 'o',
	7891 => 'o',
	7893 => 'o',
	7895 => 'o',
	7897 => 'o',
	417 => 'o',
	7899 => 'o',
	7901 => 'o',
	7903 => 'o',
	7905 => 'o',
	7907 => 'o',
	7886 => 'O',
	7884 => 'O',
	7888 => 'O',
	7890 => 'O',
	7892 => 'O',
	7894 => 'O',
	7896 => 'O',
	416 => 'O',
	7898 => 'O',
	7900 => 'O',
	7902 => 'O',
	7904 => 'O',
	7906 => 'O',
	7911 => 'u',
	361 => 'u',
	7909 => 'u',
	432 => 'u',
	7913 => 'u',
	7915 => 'u',
	7917 => 'u',
	7919 => 'u',
	7921 => 'u',
	7910 => 'U',
	360 => 'U',
	7908 => 'U',
	431 => 'U',
	7912 => 'U',
	7914 => 'U',
	7916 => 'U',
	7918 => 'U',
	7920 => 'U',
	253 => 'y',
	7923 => 'y',
	7927 => 'y',
	7929 => 'y',
	7925 => 'y',
	221 => 'Y',
	7922 => 'Y',
	7926 => 'Y',
	7928 => 'Y',
	7924 => 'Y',
	273 => 'd'

);

==> spip_4.0.4.orig.tar.xz: ecrire/charsets/translit.php <==
<?php

/**
 * Déclaration pour la translitteration simple des correspondances entre
 * caractères unicodes spécifiques et caractères simples la plage ASCII
 *
 * @package SPIP\Core\Charsets
 **/

$GLOBALS['CHARSET']['translit'] = [
// latin [fausse plage]
	128 => 'EUR',
	131 => 'f',
	140 => 'OE',
	147 => '\'\'',
	148 => '\'\'',
	153 => '(TM)',
	156 => 'oe',
	159 => 'Y',

// latin [legal]
	160 => ' ',
	161 => '!',
	162 => 'c',
	163 => 'L',
	164 => 'O',
	165 => 'yen',
	166 => '|',
	167 => 'p',
	169 => '(c)',
	171 => '<<',
	172 => '-',
	173 => '-',
	174 => '(R)',
	176 => 'o',
	177 => '+-',
	181 => 'mu',
	182 => 'p',
	183 => '.',
	186 => 'o ',
	187 => '>>',
	191 => '?',
	192 => 'A',
	193 => 'A',
	194 => 'A',
	195 => 'A',
	196 => 'A',
	197 => 'A',
	198 => 'AE',
	199 => 'C',
	200 => 'E',
	201 => 'E',
	202 => 'E',
	203 => 'E',
	204 => 'I',
	205 => 'I',
	206 => 'I',
	207 => 'I',
	209 => 'N',
	210 => 'O',
	211 => 'O',
	212 => 'O',
	213 => 'O',
	214 => 'O',
	216 => 'O',
	217 => 'U',
	218 => 'U',
	219 => 'U',
	220 => 'U',
	223 => 'ss',
	224 => 'a',
	225 => 'a',
	226 => 'a',
	227 => 'a',
	228 => 'a',
	229 => 'a',
	230 => 'ae',
	231 => 'c',
	232 => 'e',
	233 => 'e',
	234 => 'e',
	235 => 'e',
	236 => 'i',
	237 => 'i',
	238 => 'i',
	239 => 'i',
	241 => 'n',
	242 => 'o',
	243 => 'o',
	244 => 'o',
	245 => 'o',
	246 => 'o',
	248 => 'o',
	249 => 'u',
	250 => 'u',
	251 => 'u',
	252 => 'u',
	255 => 'y',

// turc
	286 => 'G',
	287 => 'g',
	304 => 'I',
	305 => 'i',
	350 => 'S',
	351 => 's',

// esperanto
	264 => 'Cx',
	265 => 'cx',
	284 => 'Gx',
	285 => 'gx',
	292 => 'Hx',
	293 => 'hx',
	308 => 'Jx',
	309 => 'jx',
	348 => 'Sx',
	349 => 'sx',
	364 => 'Ux',
	365 => 'ux',


// latin2 [Czech]
	283 => 'e',
	353 => 's',
	269 => 'c',
	345 => 'r',
	382 => 'z',
	367 => 'u',
	328 => 'n',
	357 => 't',
	271 => 'd',
	449 => 'o',
	282 => 'E',
	352 => 'S',
	268 => 'C',
	344 => 'R',
	381 => 'Z',
	366 => 'U',
	327 => 'N',
	356 => 'T',
	270 => 'D',
	467 => 'O',

// francais
	338 => 'OE',
	339 => 'oe',
	376 => 'Y',
	402 => 'f',

//polskie
	260 => 'A',
	261 => 'a',
	262 => 'C',
	263 => 'c',
	280 => 'E',
	281 => 'e',
	321 => 'L',
	322 => 'l',
	323 => 'N',
	324 => 'n',
	346 => 'S',
	347 => 's',
	377 => 'Z',
	378 => 'z',
	379 => 'Z',
	380 => 'z',

//roumain
	258 => 'A',
	259 => 'a',
	350 => 'S',
	351 => 's',
	354 => 'T',
	355 => 't',

// cyrillique
	1026 => 'D%',
	1027 => 'G%',
	8218 => '\'',
	1107 => 'g%',
	8222 => '"',
	8230 => '...',
	8224 => '/-',
	8225 => '/=',
	8364 => 'EUR',
	8240 => '0/00',
	1033 => 'LJ',
	8249 => '<',
	1034 => 'NJ',
	1036 => 'KJ',
	1035 => 'Ts',
	1039 => 'DZ',
	1106 => 'd%',
	8216 => '`',
	8217 => '\'',
	8220 => '"',
	8221 => '"',
	8226 => ' o ',
	8211 => '-',
	8212 => '--',
	8212 => '~',
	8482 => '(TM)',
	1113 => 'lj',
	8250 => '>',
	1114 => 'nj',
	1116 => 'kj',
	1115 => 'ts',
	1119 => 'dz',
	1038 => 'V%',
	1118 => 'v%',
	1032 => 'J%',
	1168 => 'G3',
	1025 => 'IO',
	1028 => 'IE',
	1031 => 'YI',
	1030 => 'II',
	1110 => 'ii',
	1169 => 'g3',
	1105 => 'io',
	8470 => 'No.',
	1108 => 'ie',
	1112 => 'j%',
	1029 => 'DS',
	1109 => 'ds',
	1111 => 'yi',
	1040 => 'A',
	1041 => 'B',
	1042 => 'V',
	1043 => 'G',
	1044 => 'D',
	1045 => 'E',
	1046 => 'ZH',
	1047 => 'Z',
	1048 => 'I',
	1049 => 'J',
	1050 => 'K',
	1051 => 'L',
	1052 => 'M',
	1053 => 'N',
	1054 => 'O',
	1055 => 'P',
	1056 => 'R',
	1057 => 'S',
	1058 => 'T',
	1059 => 'U',
	1060 => 'F',
	1061 => 'H',
	1062 => 'C',
	1063 => 'CH',
	1064 => 'SH',
	1065 => 'SCH',
	1066 => '"',
	1067 => 'Y',
	1068 => '\'',
	1069 => '`E',
	1070 => 'YU',
	1071 => 'YA',
	1072 => 'a',
	1073 => 'b',
	1074 => 'v',
	1075 => 'g',
	1076 => 'd',
	1077 => 'e',
	1078 => 'zh',
	1079 => 'z',
	1080 => 'i',
	1081 => 'j',
	1082 => 'k',
	1083 => 'l',
	1084 => 'm',
	1085 => 'n',
	1086 => 'o',
	1087 => 'p',
	1088 => 'r',
	1089 => 's',
	1090 => 't',
	1091 => 'u',
	1092 => 'f',
	1093 => 'h',
	1094 => 'c',
	1095 => 'ch',
	1096 => 'sh',
	1097 => 'sch',
	1098 => '"',
	1099 => 'y',
	1100 => '\'',
	1101 => '`e',
	1102 => 'yu',
	1103 => 'ya',

// vietnamien en translitteration de base
	7843 => 'a',
	7841 => 'a',
	7845 => 'a',
	7847 => 'a',
	7849 => 'a',
	7851 => 'a',
	7853 => 'a',
	7855 => 'a',
	7857 => 'a',
	7859 => 'a',
	7861 => 'a',
	7863 => 'a',
	7842 => 'A',
	7840 => 'A',
	7844 => 'A',
	7846 => 'A',
	7848 => 'A',
	7850 => 'A',
	7852 => 'A',
	7854 => 'A',
	7856 => 'A',
	7858 => 'A',
	7860 => 'A',
	7862 => 'A',
	7867 => 'e',
	7869 => 'e',
	7865 => 'e',
	7871 => 'e',
	7873 => 'e',
	7875 => 'e',
	7877 => 'e',
	7879 => 'e',
	7866 => 'E',
	7868 => 'E',
	7864 => 'E',
	7870 => 'E',
	7872 => 'E',
	7874 => 'E',
	7876 => 'E',
	7878 => 'E',
	7881 => 'i',
	7883 => 'i',
	7880 => 'I',
	7882 => 'I',
	7887 => 'o',
	7885 => 'o',
	7889 => 'o',
	7891 => 'o',
	7893 => 'o',
	7895 => 'o',
	7897 => 'o',
	417 => 'o',
	7899 => 'o',
	7901 => 'o',
	7903 => 'o',
	7905 => 'o',
	7907 => 'o',
	7886 => 'O',
	7884 => 'O',
	7888 => 'O',
	7890 => 'O',
	7892 => 'O',
	7894 => 'O',
	7896 => 'O',
	416 => 'O',
	7898 => 'O',
	7900 => 'O',
	7902 => 'O',
	7904 => 'O',
	7906 => 'O',
	7911 => 'u',
	361 => 'u',
	7909 => 'u',
	432 => 'u',
	7913 => 'u',
	7915 => 'u',
	7917 => 'u',
	7919 => 'u',
	7921 => 'u',
	7910 => 'U',
	360 => 'U',
	7908 => 'U',
	431 => 'U',
	7912 => 'U',
	7914 => 'U',
	7916 => 'U',
	7918 => 'U',
	7920 => 'U',
	253 => 'y',
	7923 => 'y',
	7927 => 'y',
	7929 => 'y',
	7925 => 'y',
	221 => 'Y',
	7922 => 'Y',
	7926 => 'Y',
	7928 => 'Y',
	7924 => 'Y',
	273 => 'd'

];
